@@ -45,13 +45,14 @@ impl_Bonobo_Listener_event (PortableServer_Servant servant,
 	bonobo_object_ref (BONOBO_OBJECT (listener));
 
 	if (listener->priv->event_callback)
-		bonobo_closure_invoke (listener->priv->event_callback,
-				       G_TYPE_NONE,
-				       BONOBO_TYPE_LISTENER, listener,
-				       BONOBO_TYPE_STRING, event_name,
-				       BONOBO_TYPE_CORBA_ANY, args,
-				       BONOBO_TYPE_CORBA_EXCEPTION, ev,
-				       0);
+		bonobo_closure_invoke (
+			listener->priv->event_callback,
+			G_TYPE_NONE,
+			BONOBO_TYPE_LISTENER,                       listener,
+			G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE, event_name,
+			BONOBO_TYPE_STATIC_CORBA_ANY,               args,
+			BONOBO_TYPE_STATIC_CORBA_EXCEPTION,         ev,
+			0);
 		
 	g_signal_emit (G_OBJECT (listener),
 		       signals [EVENT_NOTIFY], 0,
@@ -60,6 +61,19 @@ impl_Bonobo_Listener_event (PortableServer_Servant servant,
 	bonobo_object_unref (BONOBO_OBJECT (listener));
 }
 
+static void
+bonobo_listener_destroy (BonoboObject *object)
+{
+	BonoboListener *listener = (BonoboListener *) object;
+
+	if (listener->priv->event_callback) {
+		g_closure_unref (listener->priv->event_callback);
+		listener->priv->event_callback = NULL;
+	}
+	
+	((BonoboObjectClass *)bonobo_listener_parent_class)->destroy (object);
+}
+
 static void
 bonobo_listener_finalize (GObject *object)
 {
@@ -67,9 +81,7 @@ bonobo_listener_finalize (GObject *object)
 
 	listener = BONOBO_LISTENER (object);
 
-	if (listener->priv)
-	{
-		g_closure_unref (listener->priv->event_callback);
+	if (listener->priv) {
 		g_free (listener->priv);
 		listener->priv = 0;
 	}
@@ -80,12 +92,14 @@ bonobo_listener_finalize (GObject *object)
 static void
 bonobo_listener_class_init (BonoboListenerClass *klass)
 {
-	GObjectClass *oclass = (GObjectClass *)klass;
+	GObjectClass *oclass = (GObjectClass *) klass;
+	BonoboObjectClass *boclass = (BonoboObjectClass *) klass;
 	POA_Bonobo_Listener__epv *epv = &klass->epv;
 
 	bonobo_listener_parent_class = g_type_class_peek_parent (klass);
 
 	oclass->finalize = bonobo_listener_finalize;
+	boclass->destroy = bonobo_listener_destroy;
 
 	signals [EVENT_NOTIFY] = g_signal_new (
 		"event_notify", G_TYPE_FROM_CLASS (oclass), G_SIGNAL_RUN_LAST,
@@ -93,9 +107,9 @@ bonobo_listener_class_init (BonoboListenerClass *klass)
 		NULL, NULL,
 		bonobo_marshal_VOID__STRING_BOXED_BOXED,
 		G_TYPE_NONE, 3,
-		BONOBO_TYPE_STRING,
-		BONOBO_TYPE_CORBA_ANY,
-		BONOBO_TYPE_CORBA_EXCEPTION);
+		G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
+		BONOBO_TYPE_STATIC_CORBA_ANY,
+		BONOBO_TYPE_STATIC_CORBA_EXCEPTION);
 
 	epv->event = impl_Bonobo_Listener_event;
 }
